#
# spec file for package spek
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spek
Version:        0.8.5
Release:        2.4
Summary:        Tool for audio spectrum analysis and visualization
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://www.spek.cc/
Source:         https://github.com/alexkay/spek/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gettext >= 0.21
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)

%description
Spek helps to analyse your audio files by showing their spectrogram.
It supports all popular lossy and lossless audio file formats.

Features:
  * Ultra-fast signal processing, uses multiple threads to further
    speed up the analysis
  * Shows the codec name and the audio signal parameters
  * Can save the spectrogram as an image file
  * Drag-and-drop support; associates with common audio file formats
  * Auto-fitting time, frequency and spectral density rulers
  * Adjustable spectral density range

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} $(pkg-config --cflags-only-I libavutil)"
./autogen.sh
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -r %{name} AudioVideo Player
%find_lang %{name}

%files -f %{name}.lang
%license LICENCE.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Oct  9 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not limit to FFmpeg 5 on Tumbleweed: Upstream actually did a
  good enough job to not use deprecated APIs to even be compatible
  with ffmpeg 7.1.
* Sun Jul 16 2023 munix9@googlemail.com
- Update to version 0.8.5:
  * Update translations
  * Fix audio decoding
  * Fix decoding for m4a and ogg
  * Bump the required FFmpeg library versions
  * Replace deprecated FFmpeg APIs to support FFmpeg 5.x
  * Implement $XDG_CONFIG_HOME on Unix systems
- Use ffmpeg-5 for Factory/Tumbleweed
- Remove 232.patch (fixed upstream)
* Tue Dec 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 232.patch: Replace deprecated FFmpeg APIs to support FFmpeg
  5.x. No longer limit ffmpeg dependencies to version 4.x.x.
  https://github.com/alexkay/spek/pull/232
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.4:
  + New features since 0.8.2:
  - Add 2 more palettes and change the default.
  - Allow changing the DFT window size and function.
  - Allow switching between audio streams and channels.
  - Add translations for 14 additional languages.
  + Enhancements:
  - Remove dependency on intltool.
  - Fix FFmpeg build warnings.
  - Detect AR tool.
  - Use Homebrew for macOS dependencies.
  - Improve test coverage.
  + Bugfixes:
  - Remove association with .mod and MIDI files.
  - Fix autoconf errors.
  - Fix an AVX-related crash.
- Drop patches fixed upstream:
  + ffmpeg_2.9.patch
  + fix-compilation-with-libav-8.patch
- Changes in BuildRequires:
  + Added: libtool and explicit gettext (since version 0.21 or
    newer is needed).
  + Dropped: intltool.
- Workaround upstreams issue:
  https://github.com/alexkay/spek/issues/149
  export CXXFLAGS="$CXXFLAGS -std=gnu++11 -Wall -Wextra -I/usr/include/ffmpeg"
- Limit ffmpeg dependencies to ffmpeg-4 and older variant.
* Thu Apr 16 2020 Martin Hauke <mardnh@gmx.de>
- Complete specfile overhaul
  + Use proper BuildRequires
  + Use correct Group Tag
  + Convert inline changelog to changes file
  + Add patches to make it compile on modern systems:
  * ffmpeg_2.9.patch
  * fix-compilation-with-libav-8.patch
* Wed Oct 30 2013 Huaren Zhong <huaren.zhong@gmail.com>
- Rebuild for Fedora
  Fri Jul 12 00:00:00 UTC 2013 - fwang <fwang> 0.8.1-4.mga4
  + Revision: 453382
- fix build with recent ffmpeg
  Mon Jan 14 00:00:00 UTC 2013 - umeabot <umeabot> 0.8.1-4.mga3
  + Revision: 382517
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
  Wed Jan  9 00:00:00 UTC 2013 - malo <malo> 0.8.1-3.mga3
  + Revision: 343376
- updated RPM group (Visualization is no more)
  Tue Jan  8 00:00:00 UTC 2013 - fwang <fwang> 0.8.1-2.mga3
  + Revision: 341743
- rebuild for new ffmpeg
  Thu Nov 22 00:00:00 UTC 2012 - mitya <mitya> 0.8.1-1.mga3
  + Revision: 320424
- 0.8.1
- Created package structure for spek.
